@@ -1,13 +1,12 @@
+#!/usr/bin/perl -w
+
 package Module::InstalledVersion;
-$Module::InstalledVersion::VERSION = '0.05_01';
-use 5.006;
+
 use strict;
-use warnings;
+use Carp;
 
-use Carp ();
-use File::Spec ();
-
-our $VERSION;
+use vars '$VERSION';
+$VERSION = "0.01";
 
 =pod
 
@@ -21,7 +20,6 @@ Module::InstalledVersion - Find out what version of a module is installed
     my $m = new Module::InstalledVersion 'Foo::Bar';
     print "Version is $m->{version}\n";
     print "Directory is $m->{dir}\n";
-    print "Path is $m->{path}\n";
 
 =head1 DESCRIPTION
 
@@ -29,8 +27,21 @@ This module finds out what version of another module is installed,
 without running that module.  It uses the same regexp technique used by
 L<Extutils::MakeMaker> for figuring this out.
 
-Note that it won't work if the module you're looking at doesn't set
-$VERSION properly.  This is true of far too many CPAN modules.
+=begin testing
+
+BEGIN: { use_ok("Module::InstalledVersion", "Use Module::InstalledVersion") }
+
+foreach my $module (qw(CPAN Fcntl Text::Wrap)) {
+    if (eval "require $module" ) {
+        my $m = Module::InstalledVersion->new($module);
+        ok($m->isa("Module::InstalledVersion"), "create new object for $module");
+        is($m->{version}, ${"${module}::VERSION"}, "Picked up version of $module");
+    } else {
+        print STDERR "Can't require $module\n";
+    }
+}
+
+=end testing
 
 =cut
 
@@ -38,26 +49,26 @@ sub new {
     shift;
     my ($module_name) = @_;
     my $self = {};
-    $module_name = File::Spec->catfile(split(/::/, $module_name));
+    $module_name =~ s/::/\//g;
 
     DIR: foreach my $dir (@INC) {
-        my $filename = File::Spec->catfile($dir, "$module_name.pm");
+        my $filename = "$dir/$module_name.pm";
         if (-e $filename ) {
-            $self->{dir}  = $dir;
-            $self->{path} = $filename;
+            print "Found file $filename\n";
             if (open IN, "$filename") {
                 while (<IN>) {
-                    # the following regexp comes from the Extutils::MakeMaker
+                    # the following regexp comes from the Extutils::MakeMaker 
                     # documentation.
                     if (/([\$*])(([\w\:\']*)\bVERSION)\b.*\=/) {
                         local $VERSION;
-                        my $res = eval $_;
-                        $self->{version} = $VERSION || $res;
+                        eval $_;
+                        $self->{version} = $VERSION;
+                        $self->{dir} = $dir;
                         last DIR;
                     }
                 }
             } else {
-                Carp::carp "Can't open $filename: $!";
+                carp "Can't open $filename: $!";
             }
         }
     }
@@ -65,29 +76,16 @@ sub new {
     return $self;
 }
 
-1;
-
-=head1 SEE ALSO
-
-L<App::Mver>,
-L<App::module::version>,
-L<Module::Extract::VERSION>,
-L<Module::Info>,
-L<Module::InstalledVersion>,
-L<Module::Metadata>,
-L<Module::Version>,
-L<Parse::PMFile>.
-
-=head1 REPOSITORY
-
-L<https://github.com/neilbowers/Module-InstalledVersion>
-
 =head1 COPYRIGHT
 
 Copyright (c) 2001 Kirrily Robert.
 This program is free software; you may redistribute it
 and/or modify it under the same terms as Perl itself.
 
+=head1 SEE ALSO
+
+L<Extutils::MakeMaker>
+
 =head1 AUTHOR
 
 Kirrily "Skud" Robert <skud@cpan.org>
